(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13791,        441]*)
(*NotebookOutlinePosition[     82660,       2887]*)
(*  CellTagsIndexPosition[     82616,       2883]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Wolfram Research Technical Support", "TSBanner"],

Cell[TextData[{
  StyleBox["Engineer : ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  "harry Calkins, Wolfram Education"
}], "TSAuthor"],

Cell[CellGroupData[{

Cell["Andy's Eye", "Title"],

Cell[CellGroupData[{

Cell["A Retina Scan", "Section"],

Cell["\<\
Given a scan of a retina as a two dimensional image map it onto the \
interior of a hemisphere preserving the colormap as closely as \
possible.\
\>", "Text"],

Cell["\<\
The trick is to find an efficient color function with values taken \
from the scan and error correcting for the parts of the image that are \
cropped.\
\>", "Text"],

Cell["\<\
To get this to work you will have to make sure you have the file \
hunt-left-lowres.jpg where it can be imported and you will need to set the \
path to file in the Import function.\
\>", "Text"],

Cell["\<\
When evaluated this notebook will be between nine adn ten \
mega-bytes in size.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The scan", "Section"],

Cell[TextData[{
  "This brings the image into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and then crops the uninteresting material on the sides."
}], "Text"],

Cell[BoxData[
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(\(eyeball = Import["\<hunt-left-lowres.jpg\>"];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(newEye = eyeball[\([1, 1, All, Range[55, 445]]\)]/255. ;\)\)], "Input",\

  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\(Show[Graphics[Raster[newEye, ColorFunction\  \[Rule] \ RGBColor]], 
        AspectRatio\  \[Rule] \ Automatic];\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(\(iris = Import["\<hunt-left-iris-small.jpg\>"];\)\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(newIris = iris[\([1, 1, All, Range[55, 445]]\)]/255. ;\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(\(Show[Graphics[Raster[newIris, ColorFunction\  \[Rule] \ RGBColor]], 
        AspectRatio\  \[Rule] \ Automatic];\)\)], "Input",
  CellLabel->"In[13]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Color Function", "Section"],

Cell["\<\
Experimentation reveals that an inefficient color function can cause a kernel \
meltdown. This approach seems quite robust so long as the matrix is not too \
large.\
\>", "Text"],

Cell["\<\
Since the above image is a matrix of ordered triples and we would like to \
have the center of the image appear at the southpole of the hemisphere we \
need to find the \"center\" of the image matrix. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection"],

Cell[BoxData[
    \(Dimensions[newEye]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(Dimensions[newIris]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(cent = \(Ceiling[{333, 391, 3}/2]\)[\([{1, 2}]\)]\)], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
We will project the image onto a sphere of radius 1 so we need to create a \
set of x-y coordinates which span the matrix picking up all the information \
in the matrix. The set coords does that, and the center of the matrix has the \
coordinate {0,0}.\
\>", "Text"],

Cell[BoxData[
    \(\(coords\  = \ 
        Table[{i, j}, {i, 
              167/196, \(-167\)/196, \(-\((167/196)\)\)/166}, {j, \(-1\), 1, 
              1/195}] // N;\)\)], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
This is a function used to combine the x-y coordinates with the color values \
extracted from the image matrix.\
\>", "Text"],

Cell[BoxData[
    \(MakePointSet[lis1_List, lis2_List] := 
      Map[MapThread[Append, #] &, MapThread[List, {lis1, lis2}]]\)], "Input",
  CellLabel->"In[18]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Color functions", "Subsection"],

Cell["\<\
These steps take the color values out of the image matrix, combine them with \
our coordinate set which is then used to create an interpolating function.\
\>", "Text"],

Cell[BoxData[
    \(\(redpts = \ Map[Part[#, All, 1] &, newEye];\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(\(redfnpts = \ MakePointSet[coords, redpts];\)\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(redfun\  = \ 
      Interpolation[Flatten[redfnpts, 1], 
        InterpolationOrder \[Rule] \ 1]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(\(grnpts\  = \ Map[Part[#, All, 2] &, newEye];\)\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(\(greenfnpts = \ MakePointSet[coords, grnpts];\)\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(greenfun = \ 
      Interpolation[Flatten[greenfnpts, 1], 
        InterpolationOrder \[Rule] \ 1]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(\(blupts = \ Map[Part[#, All, 3] &, newEye];\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\(bluefnpts\  = \ MakePointSet[coords, blupts];\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(bluefun = \ 
      Interpolation[Flatten[bluefnpts, 1], 
        InterpolationOrder \[Rule] \ 1]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\(redirispts = \ Map[Part[#, All, 1] &, newIris];\)\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\(redirisfnpts = \ MakePointSet[coords, redirispts];\)\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(redirisfun\  = \ 
      Interpolation[Flatten[redirisfnpts, 1], 
        InterpolationOrder \[Rule] \ 1]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(grnirispts\  = \ Map[Part[#, All, 2] &, newIris];\)\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\(greenirisfnpts = \ MakePointSet[coords, grnirispts];\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(greenirisfun = \ 
      Interpolation[Flatten[greenirisfnpts, 1], 
        InterpolationOrder \[Rule] \ 1]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(\(bluirispts = \ Map[Part[#, All, 3] &, newIris];\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(\(blueirisfnpts\  = \ MakePointSet[coords, bluirispts];\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(blueirisfun = \ 
      Interpolation[Flatten[blueirisfnpts, 1], 
        InterpolationOrder \[Rule] \ 1]\)], "Input",
  CellLabel->"In[36]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["The function for the plot", "Subsection"],

Cell["\<\
Since we are creating a hemisphere of radius 1 and the image is clipped in \
the vertical dimension we need to account for values that will not be covered \
by the interpolating functions. To do this we use the If function to make \
sure the y-coordinate values do not get too large or too small.\
\>", "Text"],

Cell[BoxData[
    \(colrfn[t_, u__]\  := \ 
      If[\(-0.8520408163265306`\) < Sin[t]\ Cos[u] < 
            0.8520408163265306` && \(-1\) < Cos[t]\ Cos[u] < 1, 
        RGBColor[redfun[\ Sin[t]\ Cos[u], Cos[t]\ Cos[u]], 
          greenfun[\ Sin[t]\ Cos[u], Cos[t]\ Cos[u]], \ 
          bluefun[\ Sin[t]\ Cos[u], Cos[t]\ Cos[u]]], 
        RGBColor[ .263,  .169,  .129]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(colririsfn[t_, u__]\  := \ 
      If[\(-0.8520408163265306`\) < Sin[t]\ Cos[u] < 
            0.8520408163265306` && \(-1\) < Cos[t]\ Cos[u] < 1, 
        RGBColor[redirisfun[\ Sin[t]\ Cos[u], Cos[t]\ Cos[u]], 
          greenirisfun[\ Sin[t]\ Cos[u], Cos[t]\ Cos[u]], \ 
          blueirisfun[\ Sin[t]\ Cos[u], Cos[t]\ Cos[u]]], 
        RGBColor[1, 1, 1]]\)], "Input",
  CellLabel->"In[38]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The plot", "Section"],

Cell["\<\
This could undoubtedly be refined by playing with lighting and that sort of \
thing. Remember we are looking into the inside of the hemisphere in this \
rendering.\
\>", "Text"],

Cell[BoxData[
    \(\(eyeplot = 
        ParametricPlot3D[{Cos[t]\ Cos[u], Sin[t]\ Cos[u], 
            Sin[u], {FaceForm[SurfaceColor[White, White, 10], 
                SurfaceColor[colrfn[t, u], White, 10]], EdgeForm[]}}, {t, 0, 
            2\ Pi}, {u, \(-Pi\)/2, \(- .15\)}, 
          PlotPoints\  \[Rule] \ {360, 90}, 
          ViewPoint -> {0. , \ 0. , \ 3.383}, Boxed \[Rule] \ False, 
          Axes\  \[Rule] \ False, LightSources \[Rule] {{{1, 1, 1}, White}}, 
          AmbientLight \[Rule] RGBColor[ .5,  .5,  .5], 
          Background \[Rule] RGBColor[ .2,  .2,  .2], ImageSize \[Rule] 600, 
          ViewVertical \[Rule] {0, 1, 0}];\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(\(irisplot = 
        ParametricPlot3D[{Cos[t]\ Cos[u], 
            Sin[t]\ Cos[u], \(-Sin[u]\), {SurfaceColor[colririsfn[t, u], 
                White, 10], EdgeForm[]}}, {t, 0, 
            2\ Pi}, {u, \(-7.3\)\ Pi/16, \(-3\)\ Pi/8}, 
          PlotPoints\  \[Rule] \ {360, 90}, 
          ViewPoint -> {0. , \ 0. , \ 3.383}, Boxed \[Rule] \ False, 
          Axes\  \[Rule] \ False, LightSources \[Rule] {{{1, 1, 1}, White}}, 
          AmbientLight \[Rule] RGBColor[ .5,  .5,  .5], 
          Background \[Rule] RGBColor[ .2,  .2,  .2], ImageSize \[Rule] 600, 
          ViewVertical \[Rule] {0, 1, 0}];\)\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(With[{t = Pi/4}, 
      Show[eyeplot, irisplot, ViewPoint -> {Cos[t], \(-Sin[t]\), 3.383}, 
        SphericalRegion \[Rule] True, 
        ViewVertical \[Rule] {0, 1, 0}]]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(\(anim = 
        Table[Show[eyeplot, irisplot, 
            ViewPoint -> {Cos[a], \(-Sin[a]\), 3.383}, 
            SphericalRegion \[Rule] True, ViewVertical \[Rule] {0, 1, 0}, 
            ImageSize \[Rule] 400], {a, 0, 2\ \[Pi], 
            2\ \[Pi]/20}];\)\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(\(anim2 = Drop[anim, \(-1\)];\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(Export["\<eye.gif\>", anim2, "\<GIF\>", 
      ConversionOptions \[Rule] {"\<Loop\>" \[Rule] True}]\)], "Input",
  CellLabel->"In[84]:="],

Cell["\<\
This reveals the outside of the sphere and shows a portion of the inside.\
\>", "Text"],

Cell[BoxData[
    \(\(eyeplot = 
        ParametricPlot3D[{Cos[t]\ Cos[u], Sin[u], 
            Sin[t]\ Cos[u], {FaceForm[SurfaceColor[colrfn[t, u], White, 10], 
                SurfaceColor[White]], EdgeForm[]}}, {t, 0, 
            2\ Pi}, {u, \(-Pi\)/2, 0}, PlotPoints\  \[Rule] \ {360, 90}, 
          ViewPoint -> {0. , \ 0. , \ 3.383}, Boxed \[Rule] \ False, 
          Axes\  \[Rule] \ False, LightSources \[Rule] {{{1, 1, 1}, White}}, 
          AmbientLight \[Rule] RGBColor[ .5,  .5,  .5], 
          Background \[Rule] RGBColor[ .2,  .2,  .2], 
          ImageSize \[Rule] 600];\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(\(anim = 
        Table[ParametricPlot3D[{Cos[t]\ Cos[u], Sin[u], 
              Sin[t]\ Cos[u], {FaceForm[
                  SurfaceColor[colrfn[t, u], White, 10], 
                  SurfaceColor[White]], EdgeForm[]}}, {t, 0, 
              2\ Pi}, {u, \(-Pi\)/2, 0}, PlotPoints\  \[Rule] \ {360, 90}, 
            ViewPoint -> {2\ Cos[a], \ 3.383, 2\ Sin[a]}, 
            Boxed \[Rule] \ False, Axes\  \[Rule] \ False, 
            LightSources \[Rule] {{{1, 1, 1}, White}}, 
            AmbientLight \[Rule] RGBColor[ .5,  .5,  .5], 
            Background \[Rule] RGBColor[ .2,  .2,  .2], 
            ImageSize \[Rule] 400, SphericalRegion \[Rule] True], {a, 0, 
            2\ \[Pi], 2\ \[Pi]/20}];\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(Export["\<eye2.gif\>", anim, "\<GIF\>", 
      ConversionOptions \[Rule] {"\<Loop\>" \[Rule] True}]\)], "Input",
  CellLabel->"In[40]:="],

Cell["\<\
Sincerely,

harry Calkins
Wolfram Education
Wolfram Research, Inc.
support@wolfram.com\
\>", "TSClose"],

Cell[TextData[{
  "Created using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1 on Sunday, January 30, 2005"
}], "TSCloseData"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 935}},
WindowSize->{800, 805},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for Technical Support", "Subtitle"],
  
  Cell["\<\

These styles are selected for notebooks created by Technical Support for 
consumption by the end-user and also for FAQ creation.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowCellBracket->True,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

  The options defined for the style below will be used at the Notebook level. \

 
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights  \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights  \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    DefaultNewCellStyle->"Input",
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Printout"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights  \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2003 Wolfram Research, Inc. All rights  \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Section"],
  
  Cell[StyleData["TSBanner"],
    Editable->False,
    CellFrame->{{0, 8}, {0, 2}},
    CellMargins->{{0, 5}, {0, 5}},
    PageBreakBelow->False,
    CellFrameMargins->{{200, 25}, {3, 3}},
    ParagraphIndent->35,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->RGBColor[0.700008, 0, 0]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{35, 35}, {30, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    TextAlignment->Center,
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->34,
    FontWeight->"Plain",
    FontColor->RGBColor[0.700008, 0, 0]],
  
  Cell[StyleData["Title", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Title", "Presentation"],
    FontSize->36],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{35, 35}, {5, 20}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Subtitle", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSAuthor"],
    Editable->False,
    CellFrame->{{0, 8}, {2, 0}},
    CellMargins->{{0, 5}, {4, 0}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 25}, {3, 3}},
    ParagraphIndent->35,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    Background->RGBColor[0.74902, 0.694118, 0.552941]],
  
  Cell[StyleData["TSAuthor", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSAuthor", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["TSAuthor", "Printout"],
    CellMargins->{{55, 27}, {0, 0}},
    TextJustification->1,
    Hyphenation->True,
    FontSize->10,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    ShowCellBracket->True,
    CellMargins->{{35, 27}, {0, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Section",
    FontFamily->"Times",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.700008, 0, 0]],
  
  Cell[StyleData["Section", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Section", "Presentation"],
    FontSize->30],
  
  Cell[StyleData["Section", "SlideShow"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {5, 0}},
    PageBreakBelow->False,
    CellFrameMargins->{{36, 36}, {Inherited, 15}},
    FontSize->18,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0, 0]],
  
  Cell[StyleData["Section", "Printout"],
    PageBreakBelow->False,
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{50, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.611765, 0.545098, 0.345098]],
  
  Cell[StyleData["Subsection", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Subsection", "Presentation"],
    FontSize->24],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    ShowCellBracket->True,
    CellMargins->{{65, 27}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{35, 27}, {8, 11}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    ParagraphSpacing->{0, 2},
    FontSize->12],
  
  Cell[StyleData["Text", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSComment"],
    CellFrame->{{0, 1}, {0, 1}},
    CellMargins->{{27, 27}, {0, 8}},
    CellFrameColor->RGBColor[0.700008, 0, 0],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TSComment", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSComment", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSComment", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["TSComment", "Printout"],
    TextJustification->1,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSBulletedItem"],
    CellFrame->{{0, 1}, {0, 1}},
    CellMargins->{{24, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    CellFrameLabels->{{
      Cell[ "\[Bullet]", "BulletedList", CellBaseline -> Center], 
          Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"BulletText",
    StyleMenuListing->None],
  
  Cell[StyleData["TSBulletedItem", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSBulletedItem", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSBulletedItem", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSBulletedItem", "Printout"],
    CellMargins->{{16, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSBulletedItemText"],
    CellFrame->{{0, 1}, {0, 0}},
    CellMargins->{{35, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    LineSpacing->{1, 3},
    StyleMenuListing->None],
  
  Cell[StyleData["TSBulletedItemText", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSBulletedItemText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSBulletedItemText", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSBulletedItemText", "Printout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSNumberedItem"],
    CellFrame->{{0, 1}, {0, 1}},
    CellMargins->{{58, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    CellFrameLabels->{{Cell[ 
            TextData[ {
              StyleBox[ 
                CounterBox[ "NumberedItem"], "TB"], 
              StyleBox[ ".", "TB"]}], CellBaseline -> Baseline, CellSize -> {
            24, Inherited}, TextAlignment -> Right], Inherited}, {
        Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"NumberedItem",
    StyleMenuListing->None],
  
  Cell[StyleData["TSNumberedItem", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSNumberedItem", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSNumberedItem", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSNumberedItem", "Printout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSNumberedItemText"],
    CellFrame->{{0, 1}, {0, 0}},
    CellMargins->{{88, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    LineSpacing->{1, 3},
    StyleMenuListing->None],
  
  Cell[StyleData["TSNumberedItemText", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSNumberedItemText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSNumberedItemText", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSNumberedItemText", "Printout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSSubnumberedItem"],
    CellFrame->{{0, 1}, {0, 1}},
    CellMargins->{{92, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    CellFrameLabels->{{Cell[ 
            TextData[ {
              StyleBox[ 
                CounterBox[ "SubnumberedItem"], "TB"], 
              StyleBox[ ".", "TB"]}], CellBaseline -> Baseline, CellSize -> {
            24, Inherited}, TextAlignment -> Right], Inherited}, {
        Inherited, Inherited}},
    CounterIncrements->"SubnumberedItem",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["TSSubnumberedItem", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSSubnumberedItem", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSSubnumberedItem", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSSubnumberedItem", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSSubnumberedItemText"],
    CellFrame->{{0, 1}, {0, 0}},
    CellMargins->{{123, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    LineSpacing->{1, 3},
    StyleMenuListing->None],
  
  Cell[StyleData["TSSubnumberedItemText", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSSubnumberedItemText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSSubnumberedItemText", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSSubnumberedItemText", "Printout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSSubsubnumberedItem"],
    CellFrame->{{0, 1}, {0, 1}},
    CellMargins->{{126, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    CellFrameLabels->{{Cell[ 
            TextData[ {
              StyleBox[ 
                CounterBox[ "SubsubnumberedItem"], "TB"], 
              StyleBox[ ".", "TB"]}], CellBaseline -> Baseline, CellSize -> {
            24, Inherited}, TextAlignment -> Right], Inherited}, {
        Inherited, Inherited}},
    CounterIncrements->"SubsubnumberedItem",
    StyleMenuListing->None,
    CounterBoxOptions->{CounterFunction:>RomanNumeral}],
  
  Cell[StyleData["TSSubsubnumberedItem", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSSubsubnumberedItem", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSSubsubnumberedItem", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSSubsubnumberedItem", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSSubsubnumberedItemText"],
    CellFrame->{{0, 1}, {0, 0}},
    CellMargins->{{157, 27}, {4, 4}},
    CellFrameMargins->False,
    CellFrameColor->RGBColor[0.700008, 0, 0],
    LineSpacing->{1, 3},
    StyleMenuListing->None],
  
  Cell[StyleData["TSSubsubnumberedItemText", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSSubsubnumberedItemText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSSubsubnumberedItemText", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["TSSubsubnumberedItemText", "Printout"],
    CellMargins->{{9, 4}, {2, 4}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSClose"],
    Editable->False,
    CellFrame->{{0, 1}, {1, 0}},
    CellMargins->{{27, 27}, {0, 0}},
    CellFrameColor->RGBColor[0.700008, 0, 0],
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TSClose", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSClose", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSClose", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["TSClose", "Printout"],
    TextJustification->1,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSCloseData"],
    Editable->False,
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{27, 27}, {0, 0}},
    CellFrameMargins->{{8, 8}, {2, 2}},
    CellFrameColor->GrayLevel[0],
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    Background->RGBColor[0.74902, 0.694118, 0.552941]],
  
  Cell[StyleData["TSCloseData", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSCloseData", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["TSCloseData", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->10],
  
  Cell[StyleData["TSCloseData", "Printout"],
    TextJustification->1,
    Hyphenation->True,
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names.    

\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Input", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {0, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 8}}],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TSInput"],
    CellFrame->{{0, 3}, {0, 3}},
    ShowCellBracket->True,
    CellMargins->{{66, 8}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"NormalGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{0, 5}, {2, 3}},
    CellFrameColor->RGBColor[0.700008, 0, 0],
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold",
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TSInput", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["TSInput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TSInput", "SlideShow"],
    CellFrame->{{0, 0}, {0, 3}},
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {0, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 8}},
    CellFrameColor->RGBColor[0.700008, 0, 0],
    Background->RGBColor[0.811765, 0.772549, 0.662745]],
  
  Cell[StyleData["TSInput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Output", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {8, 4}}],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.611765, 0.545098, 0.345098]],
  
  Cell[StyleData["Message", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}},
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Print", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}}],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Graphics", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 4}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0.611765, 0.545098, 0.345098]],
  
  Cell[StyleData["CellLabel", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "SlideShow"]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0.611765, 0.545098, 0.345098]],
  
  Cell[StyleData["Name", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Name", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext ButtonBoxes.  The 
\"Hyperlink\" style is for links within the same Notebook, or between 
Notebooks. The others point to the various sections of the help browser. 
These styles will modify individual words or letters in a cell exclusive of 
the cell tag.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLinkText", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\

The cells below define styles that define standard ButtonFunctions, for use 
in palette buttons.
\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\

These styles are for modifying individual words or letters in a cell 
exclusive of the cell tag.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JT", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JS", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["JSB", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["RM", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["BF", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["IT", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TR", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSlant->"Italic"],
  
  Cell[StyleData["TI", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TB", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["TBI", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MR"],
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MR", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MO", "Printout"],
    FontSlant->"Oblique"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MB", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MBO", "Printout"],
    FontSlant->"Oblique"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SR", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SB", "Printout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SBColor"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBColor", "Printout"],
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Mathematica4",
    CharacterEncoding->"Mathematica4"],
  
  Cell[StyleData["M4", "Printout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Mathematica4",
    CharacterEncoding->"Mathematica4"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S9"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "Printout"],
    FontSize->9,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "Printout"],
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB9"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold",
    PrivateFontOptions->{"OperatorSubstitution"->False}],
  
  Cell[StyleData["SB9", "Printout"],
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["SB10", "Printout"],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MR10"],
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MR10", "Printout"],
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallCaps"],
    StyleMenuListing->None,
    Magnification->0.8],
  
  Cell[StyleData["SmallCaps", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["KeyboardChars"],
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["KeyboardChars", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{27, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{27, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{66, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["DisplayMath", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{66, 27}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["EquationNumber", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{66, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Brackets"],
    ShowCellBracket->True],
  
  Cell[StyleData["Program", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0, 0]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Presentation"],
    FontSize->3],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\



The item above is horizontal 0.5 pt line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 4}, {-18, 18}},
    CellFrameColor->RGBColor[0.700008, 0, 0],
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Presentation"],
    FontSize->6],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\



The item above is a ProgramTop line


\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 4}, {-10, -2}},
    CellFrameColor->RGBColor[0.700008, 0, 0],
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Presentation"],
    FontSize->6],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\



The item above is a ProgramBottom line


\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{27, 4}, {-4, 18}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeader", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageFooter", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["For compatibility", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["Footer", "Printout"]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\

The cells below define styles that are mixed in with the styles of most 
cells.  If a cell's FormatType matches the name of one of the styles defined 
below, then that style is applied between the cell's style and its own 
options. This is particularly true of Input and Output.
\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\

The cells below define styles that are used to affect the display of certain 
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" 
style defines how unmatched bracket, curly bracket, and parenthesis 
characters are displayed (typically by coloring them to make them stand out).

\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.611765, 0.545098, 0.345098]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 54, 0, 33, "TSBanner"],
Cell[1811, 53, 145, 5, 29, "TSAuthor"],

Cell[CellGroupData[{
Cell[1981, 62, 27, 0, 109, "Title"],

Cell[CellGroupData[{
Cell[2033, 66, 32, 0, 43, "Section"],
Cell[2068, 68, 168, 4, 36, "Text"],
Cell[2239, 74, 174, 4, 36, "Text"],
Cell[2416, 80, 204, 4, 53, "Text"],
Cell[2623, 86, 103, 3, 36, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2763, 94, 27, 0, 43, "Section"],
Cell[2793, 96, 173, 5, 36, "Text"],
Cell[2969, 103, 207, 5, 29, "Input"],
Cell[3179, 110, 106, 2, 29, "Input"],
Cell[3288, 114, 119, 3, 29, "Input"],
Cell[3410, 119, 172, 3, 29, "Input"],
Cell[3585, 124, 108, 2, 29, "Input"],
Cell[3696, 128, 116, 2, 29, "Input"],
Cell[3815, 132, 174, 3, 29, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4026, 140, 37, 0, 43, "Section"],
Cell[4066, 142, 188, 4, 53, "Text"],
Cell[4257, 148, 225, 4, 53, "Text"],

Cell[CellGroupData[{
Cell[4507, 156, 35, 0, 39, "Subsection"],
Cell[4545, 158, 76, 2, 29, "Input"],
Cell[4624, 162, 77, 2, 29, "Input"],
Cell[4704, 166, 107, 2, 29, "Input"],
Cell[4814, 170, 276, 5, 53, "Text"],
Cell[5093, 177, 208, 5, 29, "Input"],
Cell[5304, 184, 135, 3, 36, "Text"],
Cell[5442, 189, 161, 3, 29, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5640, 197, 37, 0, 39, "Subsection"],
Cell[5680, 199, 177, 3, 53, "Text"],
Cell[5860, 204, 104, 2, 29, "Input"],
Cell[5967, 208, 104, 2, 29, "Input"],
Cell[6074, 212, 154, 4, 29, "Input"],
Cell[6231, 218, 106, 2, 29, "Input"],
Cell[6340, 222, 106, 2, 29, "Input"],
Cell[6449, 226, 156, 4, 29, "Input"],
Cell[6608, 232, 104, 2, 29, "Input"],
Cell[6715, 236, 107, 2, 29, "Input"],
Cell[6825, 240, 154, 4, 29, "Input"],
Cell[6982, 246, 109, 2, 29, "Input"],
Cell[7094, 250, 112, 2, 29, "Input"],
Cell[7209, 254, 162, 4, 29, "Input"],
Cell[7374, 260, 111, 2, 29, "Input"],
Cell[7488, 264, 114, 2, 29, "Input"],
Cell[7605, 268, 164, 4, 29, "Input"],
Cell[7772, 274, 109, 2, 29, "Input"],
Cell[7884, 278, 115, 2, 29, "Input"],
Cell[8002, 282, 162, 4, 29, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8201, 291, 47, 0, 39, "Subsection"],
Cell[8251, 293, 320, 5, 53, "Text"],
Cell[8574, 300, 411, 8, 89, "Input"],
Cell[8988, 310, 415, 8, 89, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9452, 324, 27, 0, 43, "Section"],
Cell[9482, 326, 187, 4, 53, "Text"],
Cell[9672, 332, 691, 12, 129, "Input"],
Cell[10366, 346, 668, 12, 129, "Input"],
Cell[11037, 360, 229, 5, 49, "Input"],
Cell[11269, 367, 320, 7, 49, "Input"],
Cell[11592, 376, 89, 2, 29, "Input"],
Cell[11684, 380, 157, 3, 29, "Input"],
Cell[11844, 385, 97, 2, 36, "Text"],
Cell[11944, 389, 629, 11, 109, "Input"],
Cell[12576, 402, 765, 14, 129, "Input"],
Cell[13344, 418, 157, 3, 29, "Input"],
Cell[13504, 423, 113, 7, 119, "TSClose"],
Cell[13620, 432, 143, 5, 18, "TSCloseData"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

